woo
library
Support for doing something awesome.
More dartdocs go here.
Classes
-
Angel
-
A contract that exposes whether an instance is an angel.
-
Dev
-
A class representing a dev
-
Human
-
A base contract representing a human with a name and an age.
-
Woo
-
A concrete implementation of Human that is always an Angel.